Module: Unmagic::ComponentPartial::Helper
- Defined in:
- lib/unmagic/component_partial/helper.rb
Overview
The view helper. Mixed into ActionView by the railtie, so every template can call ‘component_partial`.
The view helper. Mixed into ActionView by the railtie, so every template can call ‘component_partial`.